*********************************************************************
*                  GESTION de VANNES
*********************************************************************


        OPT   l


*************************************
*   Creation des variables          *
*************************************
PORTA	EQU  $1000	* Port d'adresse du port A
BPROT   EQU  PORTA+$35  block protect reg
ROMBS   EQU  $E000      start of rom
EOT     EQU  $04        end of text/table
IO      EQU  $93        * Registre de controle du port d'adresse du clavier
KEYBAS  EQU  $B5F4      * Port d'adresse du clavier
LCDBAS  EQU  $B5F0      * Port d'adresse de l'afficheur
STACKBS EQU  $23FF      * debut de la pile valide pour un systeme embarque


***************
*     RAM     *
* Variables situees en RAM
***************
		ORG		$2D
		RMB		20    user stack area

		ORG		$8000			* Variable situe en RAM $ = valeur en hexadecimal, changer ladresse dassemblage
VALLSB		RMB		2			* Words should be on even boundary for portability
VALMSB		RMB		2	
COUNT	 	RMB		2
LSB	 	RMB		2 
MSB	 	RMB		2
BUF1		RMB		1			* Stockage de donnee temporaire
BUF2		RMB		1
BUF3		RMB		1
BUF4		RMB		1
BUF5		RMB		1
FLAGS		RMB		1			* Drapeau donnant la position de la vanne
AUT_OUV		RMB		1			* Drapeau autorisant l'ouverture de la vanne selon l'etat du vide	
LOC_DIS		RMB		1			* Drapeau definissant la position de la cle LOCAL/DISTANCE	
UNE_FOIS	RMB		1			* Drapeau indiquant le dernier bouton poussoir appuye
SECU		RMB		1			* Compteur evitant de rester en attente de positionnement de vanne si probleme




***************************
* Memoire ROM demarre ici *
***************************

        ORG  ROMBS    * E000
MAIN

         SEI     * SEI - set interrupt mask

         LDAA #$00   * Efface E9 EEPROM block protect
         STAA BPROT  * clear 'E9 eeprom block protect

     LDS #STACKBS   * LDS - load stack pointer

		LDAB		#1			* charge la valeur 1 dans le registre B, # = immediate adressing

		STAB		AUT_OUV			* AUT_OUV = 1  : autorisation d'ouverture de la vanne

		LDAA		#0			* charge la valeur 0 dans le registre A
		STAA		FLAGS			* FLAGS = 0    : signalisation de vanne fermee

		STAA		UNE_FOIS		* UNE_FOIS = 0 : simule le dernier appui sur BP fermeture

		STAA		SECU			* SECU = 0     : compteur de securite initialise a 0

		LDD		#0000			* charge 0 dans le registre A et 0 dans B (registre double D a 16 bits et contient les deux registres A et B)
		STD		COUNT			* COUNT = 0    : compteur de cyles initialise a 0	


********** Attente pour l'etablissement de l'alimentation de l'afficheur **********		
         JSR   DELAI    * Delai d'attente
         JSR   LCDSET   * Initialisation de l'afficheur LCD
         JSR   KEYSET   * Initialisation du clavier


********** Boucle permanente du programme principal ********** 

KEYIN

		JSR		BV_MV			* Contrle de l'etat du vide (bon vide/mauvais vide)
		JSR		VANVID			* Verification de la position de la vanne pneumatique
		JSR		LOCAL_DISTANCE		* Verification de la position de la cle LOCAL/DISTANCE
		JSR		DURVIE			* Affichage du nombre de cycles de fonctionnement

* Branchement en cas de probleme en attente (voir SECFIN)
KEYSEC
		LDY		#KEYBAS			* get keypad port address
		CLR		BUF4			* clear counter
		LDAA		#$10			* start with First Row 

LOP		CLR		$02,Y			* clear scan lines
		LDAB		$00,Y			* read keypad
		ANDB		#$F0			* mask all but data
		STAB		BUF1			* save result

		STAA		$02,Y			* send row scan
		LDAB		$00,Y			* read keypad
		ANDB		#$F0			* mask result
		CMPB		BUF1			* is there activity on this row ?
		BNE		DONE			* branch if yes	* continue si egal a 0

		LSLA					* no key here, shift for next Row
		ANDA		#$F0			* mask row counter for test
		BEQ		KEYIN			* if all rows scanned, start over

		INC		BUF4			* incriment index counter
		INC		BUF4
		INC		BUF4
		INC		BUF4
		BRA		LOP			* go scann new row


********** here if something is pressed, find the column **********
DONE		CLR		BUF3			* clear column counter
		STAB		BUF2			* save row data
LL		ANDB 		#$10			* get row number
		LDA		BUF1			* get column number
		ANDA		#$10
		CBA					* match found ?
		BNE		FOUND			* branch if yes	
		INC		BUF3			* incriment counter
		LSR		BUF1			* shift for next column
		LSR		BUF2			* shift for next row
		LDAB		BUF2			* get row data
		BNE		LL			* go check next	* continue si egal a 0
		
********** si une touche a ete pressee, passage a FOUND **********
FOUND		CMPA		BUF5			* same key as pressed last time ?
		BEQ		DD			* branch if no		
		STAA		BUF5			* save key for debounce
		JMP		KEYIN			* ANTI REBOND
		
DD		LDD		#TABLE			* load look up table	
		ADDB		BUF3			* add column index
		ADDB		BUF4			* add row index
		XGDY					* prepare for table read
		LDAA		0,Y			* get the table data at this location
		
********** action sur la vanne selon le bouton poussoir presse **********
APRES		LDAB		#0			* charge la valeur 0 dans le registre B

		CMPB		AUT_OUV			* Si AUT_OUV=0, pas d'autorisation d'ouverture
		BEQ		FIN			*  et actions sur les poussoirs non prises en compte
		CMPB		LOC_DIS			* Si LOC_DIS=0 (cle en DISTANCE), actions
		BEQ		FIN			*  sur les poussoirs non prises en compte
		
********** test pour eviter de compter plusieurs cycles consecutifs **********
		LDAB		UNE_FOIS		* Comparaison de UNE_FOIS et FLAGS : si differents, alors vanne	
		CMPB		FLAGS			*  en position intermediaire et comptage plusieurs cycles possible
		BNE		SECFIN			* Dans ce cas, nouveau passage par BP1/BP2 evite : pas d'autre cycle compte* continue si egal a 0

BP1		CMPA		#$31			* BP ouverture (#31) appuye ?
		BNE		BP2			* Si non, branchement a BP2
		LDAB		#1			* charge la valeur 1 dans le registre B
		CMPB		FLAGS			* Comparaison de l'accu. B avec FLAGS 
		BEQ		FIN			* Si FLAGS=1 (vanne ouverte), pas de decompte
		JSR		DECADE			* Si FLAGS=0 (vanne fermee), decompte de l'ouverture
		LDX		#PORTA			* Le registre IX adresse maintenant la valeur que vaut PORTA
		BSET		0,X %00100000		* Ouverture vanne (PA5=1) % = adresse en binaire, X = designe le index registre,
		LDAB		#1			* Remise a 1 de l'accu. B modifie par l'appel a DECADE
		STAB		UNE_FOIS		* UNE_FOIS=1 (B=1), indique BP ouverture a deja ete appuye
		JMP		FIN			* se rend a FIN

BP2		CMPA		#$32			* BP fermeture (#32) appuye ?
		BNE		FIN			* Si non, branchement a FIN		* continue si egal a 0
		LDAB		#0			* charge la valeur 0 dans le registre B
		CMPB		FLAGS			* Comparaison de l'accu. B avec FLAGS 
		BEQ		FIN			* Si FLAGS=1 (vanne fermee), pas de decompte	* branchement conditionnel sur FIN
		JSR		DECADE			* Si FLAGS=0 (vanne ouverte), decompte de la fermeture
		LDX		#PORTA			* Le registre IX adresse maintenant la valeur de PORTA
		BCLR		0,X %00100000		* Fermeture vanne (PA5=0)	* met a 0 le bit 5 de loctet qui est a ladresse de registre X
		LDAB		#0			* Remise a 0 de l'accu. B modifie par l'appel a DECADE	* charge la valeur 0 dans le registre B
		STAB		UNE_FOIS		* UNE_FOIS=0, indique BP fermeture appuye en dernier
		
SECFIN		INC		SECU			* Boucle de securite permettant de ne pas rester indefiniment
		LDAB		#10			*  en attente de changement d'etat de FLAGS si la vanne se	* charge la valeur 10 dans le registre B
		CMPB		SECU			*  bloque en position intermediaire ou si les cbles sont coupes.
		BNE		FIN			*  Dans ces deux cas, FLAGS=0 et la vanne est consideree fermee,	* continue si egal a 0
		LDAB		#1			*  d'o impossibilite de fermer avec le BP.	* charge la valeur 1 dans le registre B
		STAB		UNE_FOIS		* Si attente trop longue :
		STAB		FLAGS			*  SECU arrive a 10, UNE_FOIS et FLAGS sont mis a 1 (vanne
		STAB		SECU			*  ouverte simulee) et la fermeture est ainsi autorisee en
		JMP		KEYSEC			*  evitant le passage par VANVID qui modifierait FLAGS.	* se rend a KEYSEC
		
FIN		JSR		DELAY			* Fin de la boucle permanente.
		JMP		KEYIN			* se rend a KEYIN





*******************
*** TEXT TABLES ***

MSG1		FCC		"Vanne VSC703 ouverte"        
		FCB		EOT		
MSG2		FCC		"Vanne VSC703 fermee "
		FCB		EOT	
MSG3  		FCC		"  Vide/pression OK  "        
		FCB		EOT	
MSG4		FCC		"Defaut vide/pression"
		FCB		EOT	
MSG5  		FCC		"      DISTANCE      "        
		FCB		EOT
MSG6		FCC		"       LOCAL        "
		FCB		EOT
MSG7  		FCC		" Nbre cycles: "        
		FCB		EOT


TABLE		FCB		$31,$32,$33,$34		* Visualisation de la table de la matrice du clavier
		FCB		$35,$36,$37,$38		* stocker des octets en memoire
		FCB		$39,$41,$42,$43		* stocker des octets en memoire
		FCB		$44,$45,$46,$30		* stocker des octets en memoire




***************************************************************************************
*
*   LISTE DES FONCTIONS - SOUS PROGRAMMES
*
***************************************************************************************



***************************************************************************************
*********************
* Delai attente
*********************
* On charge la valeur $FFFF dans le registre, puis on decremente, jusqu'a arriver a 0
* Cela permet donc de perdre du temps
DELAI
         PSHY          * Sauvegarde des registres X, Y, A et B
         LDY   #$FFFF   * On met $FFFF dans le registre Y
DELAIA   DEY            * On enleve 1 au registre Y
         BNE   DELAIA   * si le registre Y n'est pas egal a 0, alors on va sur DelaiA
         PULY           * On restaure les valeurs des registres X, Y, A et B
         RTS            * on retourne au programme


***************************************************************************************
*********************
* Delai attente pour afficheur LCD
*********************
TEMPO
		PSHB				* Sauvegarde les registres
		PSHA
		LDAB		#$16		* Activation de la boucle compteur 1
TEMP1		LDAA		#$16		* Activation de la boucle compteur 2
TEMP2		DECA				* Decremente le compteur 2
		BNE		TEMP2		* Branchement si non egal a 0
		DECB				* Decremente le compteur 1
		BNE		TEMP1		* Branchement si non egal a 0
		PULA				* Restaure les registres
		PULB
		RTS
				

***************************************************************************************
*********************
* Delai attente pour clavier
*********************		
DELAY
		PSHB				* Sauvegarde les registres
		PSHA
		LDAB		#$F0		* Activation de la boucle compteur 1
DEL1		LDAA		#$F0		* Activation de la boucle compteur 2
DEL2		DECA				* Decremente le compteur 2
		BNE		DEL2		* Branchement si non egal a 0
		DECB				* Decremente le compteur 1
		BNE		DEL1		* Branchement si non egal a 0
		PULA				* Restaure les registres
		PULB
		RTS
		




***************************************************************************************
*********************
* Allume LED verte
*********************
LEDVERT

         PSHY  * Sauvegarde des registres
         LDY   #$1000   * On met l'adresse $1000 (port A) dans le registre Y
         BSET  0,Y $20  * on met le bit 5 de l'adresse $1000 (port A)  1
         PULY  * restauration des registres
         RTS            * on retourne au programme


***************************************************************************************
*********************
* Allume LED rouge
*********************
LEDROUGE
         LDY   #$1000   * On met l'adresse $1000 (port A) dans le registre X
         BCLR  0,Y $20  * on met le bit 5 de l'adresse $1000 (port A)  0
         RTS            * on retourne au programme


***************************************************************************************
*************************
* Configuration clavier 
**************************	
KEYSET
         LDAA   #IO      *  Rcupre la valeur de configuration du clavier
         STAA   KEYBAS+3 * Validation de l'adresse clavier
         RTS


***************************************************************************************
*****************************************************************************
*          Configuration de l'afficheur 
*****************************************************************************
LCDSET
* $3C Display Function (default 2x40 size)
         LDAA  #$3C		* $3C valid pour un afficheur 4x20 ou $38 pour un afficheur 2x16
         STAA  LCDBAS

         JSR   DELAI           * On laisse du temps s'ecouler

* $01 Clear Display, Cursor to Home
         LDAA  #$01		* Effacement de l'afficheur et mise en position Home du curseur
         STAA  LCDBAS

         JSR   DELAI           * On laisse du temps s'ecouler

* $06 Cursor Increment, Shift off
         LDAA  #$06		* Met l'afficheur en position On Display
         STAA  LCDBAS

         JSR   DELAI           * On laisse du temps s'ecouler

* $0C Display on, Cursor and Cursor Blink off
         LDAA  #$0C		* Dplacement du curseur activ	
         STAA  LCDBAS

* $01 Clear Display, Cursor to Home
         LDAA  #$01		* Dplacement du curseur sur la gauche	
         STAA  LCDBAS

* $02 Cursor to Home
         LDAA  #$02		* Dplace le curseur en position Home
         STAA  LCDBAS

         JSR   DELAI           * On laisse du temps s'ecouler

         RTS


***************************************************************************************
***********************************************
* Conversion Decimal-ASCII pour afficheur LCD 
**********************************************
* La valeur a afficher est sur un octet (8 bits)
CONVDECASC		
		PSHA                                    * push A onto stack  * on sauve le registre A
		ANDA		#%11110000		* Conversion Decimal-ASCII du poids fort MSB registre A pour l'afficheur
		LSRA                                    * logical shift right A - on deplace de 1 bit vers la droite
		LSRA
		LSRA
		LSRA
		ADDA		#$30			* Ajoute la valeur hexa 30 au registre A
		LDAB		#$94+#14		* Position d'affichage (debut 3 ligne = $94)	* charge une valeur dans le registre B
		STAB		LCDBAS			* Validation position d'affichage
		JSR		TEMPO                   * delai attente
		STAA		LCDBAS+1		* write data to lcd output port  * envoi du caractere sur l'ecran
		PULA                                    * pull A from stack * on restaure le registre A
		
		ANDA		#%00001111		* Conversion Decimal-ASCII du poids faible LSB registre B pour l'afficheur
		ADDA		#$30			* Ajoute la valeur hexa 30 au registre A
		LDAB		#$94+#15		* Position d'affichage		* charge une valeur dans le registre B
		STAB		LCDBAS			* Validation position d'affichage
		
		JSR		TEMPO
		STAA		LCDBAS+1		* write data to lcd output port
		
        	RTS
		

***************************************************************************************
***********************************************
* Envoi des informations vers l'afficheur 
**********************************************
* 1) petit temps d'attente
* 2) On met dans le registre A le caractere se trouvant a l'adresse indique par X
* 3) On compare ce caractere avec la valeur #EOT (caractere nul)
* 4) si les 2 caracteres sont identiques, alors on quitte le sous programme, sinon, on continue
* 5) On augmente de 1 la valeur de X (afin de pointer le caractere suivant a afficher)
* 6) on sauve la valeur de X dans le STACK
* 7) On envoie le caractere stocke dans le registre A pour qu'il s'affiche a l'ecran a l'endroit prevu
* 8) On restaure la valeur de X
* 9) on fait un branchement toujours vrai vers LCDOUT pour retourner au debut

LCDOUT
		JSR		TEMPO
		LDAA		0,X			* charge la valeur (0 + valeur registre X) dans le registre A
		CMPA		#EOT
		BEQ		FINCA			* branchement conditionnel sur FINCA
		INX					* augmente de 1 ladresse
		PSHX
		STAA		LCDBAS+1		* write data to lcd output port
		PULX
		BRA		LCDOUT
FINCA		NOP
		RTS
	

***************************************************************************************
***********************************************
* Convertisseur HEX-Decimal du compteur de cycles  
**********************************************
			
CONVAFF
		TSX                     * transfer from SP to index reg. X
		DEX                     * decrement index register X (-1)
		DEX     
		TAB                     * transfer from acc. A to acc. B
		CLRA                    * efface registre A
		STAA		0,X     
		INCA	                * increment A (+1)				
HEXDC0		PSHA			* sauvegarde de A
		LSRB
		BCC		HEXDC1		branch if carry clear
		ADDA		0,X			* Ajoute la valeur (0 + valeur registre X) au registre A
		DAA
		STAA		0,X
HEXDC1		PULA                    * restauration de A
		PSHB
		TAB
		ABA                       * add accumulator B to accumulator A
		PULB
		DAA
		BCS		FINIT
		CMPB		#0
		BNE		HEXDC0			* continue si egal a 0		
FINIT		LDAB		0,X			
		CLRA
		STA		MSB
		STB		LSB
		LDAB		LSB			* charge la valeur LSB dans le registre B
		LDAA		MSB			* charge la valeur MSB dans le registre A
	
		RTS


***************************************************************************************
***********************************************
* Nombre de cycles de fonctionnement de la vanne  
**********************************************

DURVIE
		LDX		#MSG7			* Message " Nbre cycles "	* Le registre IX adresse maintenant l'espace MSG7
		LDAB		#$94			* Initialise position ligne afficheur (3 ligne = $94)	
		STAB		LCDBAS			* Ecrire a partir de cette position
		JSR		LCDOUT			* Envoi le message vers l'afficheur
		LDD		COUNT			* Charge valeur du compteur
		PSHA
		PSHB
		TBA
		JSR		CONVAFF			* Conversion Hexadecimal
		STD		VALLSB			* Sauvegarde la valeur convertie du poids faible compteur (LSB du Registre D)
		LDD		COUNT			* Charge valeur du compteur
		JSR		CONVAFF			* Conversion Hexadecimal
		STD		VALMSB			* Sauvegarde la valeur convertie du poids fort compteur (MSB du Registre D)
		TBA
		JSR		CONVDECASC		* Conversion Decimal-ASCII vers afficheur
		LDD		VALLSB			* Chargement valeur LSB dans le registre D
		TBA
		JSR		CONVDECASC		* Conversion Decimal-ASCII vers afficheur
		PULB					* Retourne la valeur du compteur avant conversion LSB registre D
		PULA					* Retourne la valeur du compteur avant conversion MSB registre D
		RTS


***************************************************************************************
***********************************************
* Etat du contact a cle LOCAL/DISTANCE  
**********************************************
* Cette fonction sert a afficher sur l'ecran LCD, le mode dans lequel on se trouve (local ou distant)
LOCAL_DISTANCE
		LDX		#PORTA			* Verification de l'etat de PA2:
		LDAA		#04			* si PA2=1 defaut cle en LOCAL // si PA2=0, cle en DISTANCE	
* 0000 0100
		BITA		0,X			* BITA: ET bit a bit, Z(CCR)=1 si resultat du ET est nul (soit PA2=0)
* BITA ==> bit test A
		BEQ		DIST			* Si PA2 est a 1, branchement a DIST (BEQ: test de Z du CCR, branch. si Z=1) * branchement conditionnel sur DIST

		LDAB		#1			* Si cle en position LOCAL,	
		STAB		LOC_DIS			*    alors LOC_DIS=1
		
		LDX		#MSG6			* Message " LOCAL "	* Le registre IX adresse maintenant l'espace MSG6
		LDAB		#$D4			* Chargement de l'adresse
		STAB		LCDBAS			*    d'affichage (4 ligne = $D4)
		JSR		LCDOUT			* Envoi a l'afficheur
		
		JMP		SALUT			* Saut a SALUT	* se rend a SALUT
		
DIST		LDAB		#0			* Si cle en position DISTANCE,
		STAB		LOC_DIS			*    alors LOC_DIS=0
		
		LDX		MSG5			* Message " DISTANCE "	* Le registre IX adresse maintenant l'espace MSG5
		LDAB		#$D4			* Chargement de l'adresse	
		STAB		LCDBAS			*    d'affichage (1 ligne = $D4)
		JSR		LCDOUT			* Envoi a l'afficheur

SALUT		RTS
		

***************************************************************************************
***********************************************
* Etat Bon(ne) vide/pression ou Mauvais(e) vide/pression   
**********************************************
* Cette fonction sert a afficher sur l'ecran LCD, si le vide est bon ou pas
BV_MV	
		LDX		#PORTA			* Verification de l'etat de PA1:	* Le registre IX adresse maintenant l'espace PORTA
* PORTA	= $1000
		LDAA		#02			*  si PA1=1 defaut vide/pression // si PA1=0: vide/pression ok	* charge la valeur 02 dans le registre A
* 0000 0010
		BITA		0,X			* BITA: ET bit a bit, Z(CCR)=1 si resultat du ET est nul (soit PA1=0)
		BEQ		B_V			* Si PA1 est a 0, branchement a B_V (BEQ: test de Z du CCR, branch. si Z=1)	* branchement conditionnel sur B_V

		LDX		#MSG4			* Message " Defaut vide/pression "	* Le registre IX adresse maintenant l'espace MSG4
		LDAB		#$80			* Chargement de l'adresse	* charge la valeur hexa 80 dans le registre B
		STAB		LCDBAS			*    d'affichage (1 ligne = $80)
		JSR		LCDOUT			* Envoi a l'afficheur
		
		JMP		M_V			* Saut a M_V	* se rend a M_V
		
B_V		LDAB		#1			* Si bon vide, alors autorisation	
		STAB		AUT_OUV			*    d'ouverture de la vanne (AUT_OUV=1)
		
		LDX		#MSG3			* Message " Vide/pression ok "* Le registre IX adresse maintenant l'espace MSG3
		LDAB		#$80			* Chargement de l'adresse	
		STAB		LCDBAS			*    d'affichage (1 ligne = $80)
		JSR		LCDOUT			* Envoi a l'afficheur
		
		BRA		SORTIE			* Branchement a SORTIE

M_V		LDAB		#0			* Si mauvais vide, alors pas d'autorisation	* charge la valeur 0 dans le registre B
		STAB		AUT_OUV			*    d'ouverture de la vanne (AUT_OUV=0)
		
		LDX		#PORTA			* Adresse du port A dans le registre X	
		BCLR		0,X %00100000		* Fermeture autoritaire de la vanne (PA5=0)	
* met a 0 le bit 5 de loctet qui est a ladresse de registre X
		
		LDAB		#0			* charge la valeur 0 dans le registre B		
		STAB		UNE_FOIS		* UNE_FOIS=0: autorise l'appui sur BP ouverture
		CMPB		FLAGS			* Verif. etat de FLAGS (indicateur de position de la vanne)
		BEQ		SORTIE			* Si FLAGS=0, la vanne est fermee, donc pas d'action comptee
		JSR		DECADE			* Si FLAGS=1, la vanne est ouverte et la fermeture comptee
		JSR		DELAY			* Delai pour eviter de compter 2 fermetures de vanne
		
SORTIE		RTS


***************************************************************************************
***********************************************
* Decade du compteur    
**********************************************
* Sert a compter le nombre de fermetures de la vanne
DECADE	
		LDD		COUNT			* Si le compteur est inferieur a 99 (63 hexa.),	
		CMPB		#$63			* sa valeur incrementee de 1 reste 
		BLO		OKNBR1			* contenue dans l'accu B: 00  XX  (valeur du compteur XX = 99 max.)
		CLRB					* A B 
		ADDA		#$1			* Si le compteur est egal a 99, sa valeur incrementee de 1 est ecrite	
		JMP		ENCORE			* sur les deux accus par la mise a 0 de l'accu B et l'increment de 1	
OKNBR1		ADDD		#$1			* de l'accu A, par ex.:  00 99 -> 01 00 (puis 01 99 -> 02 00, etc...)
ENCORE		STD		COUNT			*  A   B    A   B       A   B    A   B

		RTS


***************************************************************************************
***********************************************
* Etat Position Vanne VO/VF
**********************************************
* Affiche sur l'ecran LCD si la vanne est fermee ou ouverte
VANVID
		LDX		#PORTA			* Verification de l'etat de PA0:
		LDAA		#01			*   si PA0=1, vanne fermee // si PA0=0, vanne ouverte 
		BITA		0,X			* BITA: ET bit a bit, Z(CCR)=1 si resultat du ET est nul (soit PA0=0)
		BEQ		V_O			* Si PA0 est a 0, branchement a V_O (BEQ: test de Z du CCR, branch. si Z=1)
										
		LDAA		#0			* charge la valeur 0 dans le registre A
		STAA		FLAGS			* FLAGS=0 (vanne fermee)
		
		LDX		#MSG2			* Message " Vanne VSC 703 fermee "
		LDAB		#$C0			* Chargement de l'adresse	
		STAB		LCDBAS			*    d'affichage (2 ligne = $C0)
		JSR		LCDOUT			* Envoi a l'afficheur
		
		JMP		V_F			* se rend a Vanne Fermee
		
V_O
		LDAA		#1			* charge la valeur 1 dans le registre A
		STAA		FLAGS			* FLAGS=1 (vanne ouverte)
		
		LDX		#MSG1			* Message " Vanne VSC 703 ouverte "* Le registre IX adresse maintenant l'espace MSG1
		LDAB		#$C0			* Chargement de l'adresse
		STAB		LCDBAS			*    d'affichage (2 ligne = $C0)
		JSR		LCDOUT			* Envoi a l'afficheur
	
V_F		JSR		DELAY
		RTS







* On se place sur le vecteur de reset
        org     $FFFE        set the reset vector
        fdb     MAIN         * $E000


         END
